@@ -74,7 +74,7 @@ class AutoDiseqc(ConfigListScreen, Screen):
 			eDVBFrontendParametersSatellite.Inversion_Off,
 			235,
 			eDVBFrontendParametersSatellite.System_DVB_S,
-			eDVBFrontendParametersSatellite.Modulation_Auto,
+			eDVBFrontendParametersSatellite.Modulation_QPSK,
 			eDVBFrontendParametersSatellite.RollOff_auto,
 			eDVBFrontendParametersSatellite.Pilot_Unknown,
 			eDVBFrontendParametersSatellite.No_Stream_Id_Filter,
@@ -432,6 +432,8 @@ class AutoDiseqc(ConfigListScreen, Screen):
 					config.Nims[self.feid].simpleDiSEqCSetCircularLNB.value = True
 					self.circular_setup = 2
 
+			config.Nims[self.feid].configMode.value = "simple"
+
 			self.saveAndReloadNimConfig()
 			self.state += 1
 
